==> cdk8s-mongo-sts-0.0.1.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.0.1 (2021-02-06)


### Bug Fixes

* .projenrc.js ([df416b0](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/df416b0410f4c8d77adb4bad36168f30fb7b0297))
* .projenrc.js ([f24245f](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/f24245f2a47fdef58841ab93075aa63f37643c58))
* .projenrc.js ([2808a5a](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/2808a5a9e0e80eb338301f5e7d84b83130090e12))
* anti-tamper check ([5aaf344](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/5aaf3446b8e72d9ccbdc05ba4995d102b05564c0))
* tamper checks ([73bde55](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/73bde55c820ba71c15f35b0e0af7d9c0b5c1f968))
* tamper checks ([378e2dc](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/378e2dc808114454758dcedff75de89c28150252))
* yarn.lock file ([9ce54a9](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/9ce54a902d73c489f1608286e645d2828ff0e764))
* yarn.lock file ([b56f244](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/b56f24446144de310920e52f3bbb5313ee3e3532))
* yarn.lock file ([414317b](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/414317b81e0452861521576fa283fb1c65b41bd7))
* yarn.lock file ([d30d43b](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/d30d43b3867b033681d0d025cc6abcbe7cfa6ff5))
* yarn.lock file ([76c1a0c](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/76c1a0cf8a64a87fd0f319b5ea9ca4fe14983b66))
* yarn.lock file ([6cf7d46](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/6cf7d46efc0fc83c42ff1489deeceeebcef6f2cc))

==> cdk8s-mongo-sts-0.0.2.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.2](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/compare/v0.0.1...v0.0.2) (2021-02-06)

### 0.0.1 (2021-02-06)


### Bug Fixes

* .projenrc.js ([df416b0](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/df416b0410f4c8d77adb4bad36168f30fb7b0297))
* .projenrc.js ([f24245f](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/f24245f2a47fdef58841ab93075aa63f37643c58))
* .projenrc.js ([2808a5a](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/2808a5a9e0e80eb338301f5e7d84b83130090e12))
* anti-tamper check ([5aaf344](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/5aaf3446b8e72d9ccbdc05ba4995d102b05564c0))
* tamper checks ([73bde55](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/73bde55c820ba71c15f35b0e0af7d9c0b5c1f968))
* tamper checks ([378e2dc](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/378e2dc808114454758dcedff75de89c28150252))
* yarn.lock file ([9ce54a9](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/9ce54a902d73c489f1608286e645d2828ff0e764))
* yarn.lock file ([b56f244](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/b56f24446144de310920e52f3bbb5313ee3e3532))
* yarn.lock file ([414317b](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/414317b81e0452861521576fa283fb1c65b41bd7))
* yarn.lock file ([d30d43b](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/d30d43b3867b033681d0d025cc6abcbe7cfa6ff5))
* yarn.lock file ([76c1a0c](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/76c1a0cf8a64a87fd0f319b5ea9ca4fe14983b66))
* yarn.lock file ([6cf7d46](https://github.com/Hunter-Thompson/cdk8s-mongo-sts/commit/6cf7d46efc0fc83c42ff1489deeceeebcef6f2cc))
